@@ -4,28 +4,32 @@ Fasta file -> Faidx -> Fasta -> FastaRecord -> Sequence
 """
 
 from __future__ import division
+
 import os
+import re
+import string
 import sys
+import warnings
+from collections import namedtuple
+from itertools import islice
+from math import ceil
 from os.path import getmtime
-from six import PY2, PY3, string_types, integer_types
+from threading import Lock
+
+from six import PY2, PY3, integer_types, string_types
 from six.moves import zip_longest
+
 try:
     from collections import OrderedDict
 except ImportError:  #python 2.6
     from ordereddict import OrderedDict
-from collections import namedtuple
-import re
-import string
-import warnings
-from math import ceil
-from threading import Lock
 
 if sys.version_info > (3, ):
     buffer = memoryview
 
 dna_bases = re.compile(r'([ACTGNactgnYRWSKMDVHBXyrwskmdvhbx]+)')
 
-__version__ = '0.5.8'
+__version__ = '0.5.9.2'
 
 
 class KeyFunctionError(ValueError):
@@ -301,7 +305,7 @@ class IndexRecord(
         return tuple.__getitem__(self, key)
 
     def __str__(self):
-        return "{rlen:n}\t{offset:n}\t{lenc:n}\t{lenb:n}\n".format(
+        return "{rlen:d}\t{offset:d}\t{lenc:d}\t{lenb:d}".format(
             **self._asdict())
 
     def __len__(self):
@@ -456,7 +460,7 @@ class Faidx(object):
     def _index_as_string(self):
         """ Returns the string representation of the index as iterable """
         for k, v in self.index.items():
-            yield '\t'.join([k, str(v)])
+          yield '{k}\t{v}\n'.format(k=k, v=str(v))
 
     def read_fai(self):
         try:
@@ -603,7 +607,7 @@ class Faidx(object):
     def write_fai(self):
         with self.lock:
             with open(self.indexname, 'w') as outfile:
-                for line in self._index_as_string:
+                for line in self._index_as_string():
                     outfile.write(line)
 
     def from_buffer(self, start, end):
@@ -655,11 +659,12 @@ class Faidx(object):
 
         # Calculate offset (https://github.com/samtools/htslib/blob/20238f354894775ed22156cdd077bc0d544fa933/faidx.c#L398)
         newlines_before = int(
-            (start0 - 1) / i.lenc * (i.lenb - i.lenc)) if start0 > 0 and i.lenc else 0
-        newlines_to_end = int(end / i.lenc * (i.lenb - i.lenc)) if i.lenc else 0
+            (start0 - 1) / i.lenc) if start0 > 0 and i.lenc else 0
+        newlines_to_end = int(end / i.lenc) if i.lenc else 0
         newlines_inside = newlines_to_end - newlines_before
-        seq_blen = newlines_inside + seq_len
-        bstart = i.offset + newlines_before + start0
+        newline_blen = i.lenb - i.lenc
+        seq_blen = newlines_inside * newline_blen + seq_len
+        bstart = i.offset + newlines_before * newline_blen + start0
         if seq_blen < 0 and self.strict_bounds:
             raise FetchError("Requested coordinates start={0:n} end={1:n} are "
                              "invalid.\n".format(start, end))
@@ -670,7 +675,7 @@ class Faidx(object):
         with self.lock:
             if self._bgzf:  # We can't add to virtual offsets, so we need to read from the beginning of the record and trim the beginning if needed
                 self.file.seek(i.offset)
-                chunk = start0 + newlines_before + newlines_inside + seq_len
+                chunk = start0 + (newlines_before * newline_blen) + (newlines_inside * newline_blen) + seq_len
                 chunk_seq = self.file.read(chunk).decode()
                 seq = chunk_seq[start0 + newlines_before:]
             else:
@@ -1015,7 +1020,7 @@ class Fasta(object):
     def __getitem__(self, rname):
         """Return a chromosome by its name, or its numerical index."""
         if isinstance(rname, integer_types):
-            rname = tuple(self.keys())[rname]
+            rname = next(islice(self.records.keys(), rname, None))
         try:
             return self.records[rname]
         except KeyError:
@@ -1025,9 +1030,8 @@ class Fasta(object):
         return 'Fasta("%s")' % (self.filename)
 
     def __iter__(self):
-        for rname in self.keys():
-            yield self[rname]
-            
+        return iter(self.records.values())
+
     def __len__(self):
         """Return the cumulative length of all FastaRecords in self.records."""
         return sum(len(record) for record in self)
